pub struct Certificate {
pub network_id: NetworkId,
pub height: Height,
pub prev_local_exit_root: LocalExitRoot,
pub new_local_exit_root: LocalExitRoot,
pub bridge_exits: Vec<BridgeExit>,
pub imported_bridge_exits: Vec<ImportedBridgeExit>,
pub metadata: Metadata,
pub aggchain_data: AggchainData,
pub custom_chain_data: Vec<u8>,
pub l1_info_tree_leaf_count: Option<u32>,
}Expand description
Represents the data submitted by the chains to the AggLayer.
The bridge exits plus the imported bridge exits define the state transition, resp. the amount that goes out and the amount that comes in.
The bridge exits refer to the [BridgeExit] emitted by
the origin network of the Certificate.
The imported bridge exits refer to the [BridgeExit] received and imported
by the origin network of the Certificate.
Note: be mindful to update the Self::hash method accordingly
upon modifying the fields of this structure.
Fields
network_id: NetworkIdNetworkID of the origin network.
height: HeightSimple increment to count the Certificate per network.
prev_local_exit_root: LocalExitRootPrevious local exit root.
new_local_exit_root: LocalExitRootNew local exit root.
bridge_exits: Vec<BridgeExit>List of bridge exits included in this state transition.
imported_bridge_exits: Vec<ImportedBridgeExit>List of imported bridge exits included in this state transition.
metadata: MetadataFixed size field of arbitrary data for the chain needs.
aggchain_data: AggchainDataAggchain data for the certificate.
custom_chain_data: Vec<u8>l1_info_tree_leaf_count: Option<u32>Implementations
Sourceimpl Certificate
impl Certificate
pub fn wallet_for_test(network_id: NetworkId) -> PrivateKeySigner
pub fn get_signer(&self) -> Address
pub fn new_for_test(network_id: NetworkId, height: Height) -> Self
pub fn new_for_test_with_version( network_id: NetworkId, height: Height, version: SignatureCommitmentVersion, ) -> Self
Sourcepub fn new_for_test_custom(
network_id: NetworkId,
height: Height,
prev_local_exit_root: LocalExitRoot,
num_bridge_exits: usize,
aggchain_data_type: AggchainDataType,
version: SignatureCommitmentVersion,
) -> Self
pub fn new_for_test_custom( network_id: NetworkId, height: Height, prev_local_exit_root: LocalExitRoot, num_bridge_exits: usize, aggchain_data_type: AggchainDataType, version: SignatureCommitmentVersion, ) -> Self
Generate a certificate with random bridge exits and custom parameters.
pub fn with_new_local_exit_root( self, new_local_exit_root: LocalExitRoot, ) -> Self
Sourceimpl Certificate
impl Certificate
Sourcepub fn retrieve_signer(
&self,
version: SignatureCommitmentVersion,
) -> Result<Address, SignerError>
pub fn retrieve_signer( &self, version: SignatureCommitmentVersion, ) -> Result<Address, SignerError>
Retrieve the signer from the certificate signature.
Sourceimpl Certificate
impl Certificate
pub fn hash(&self) -> CertificateId
Sourcepub fn l1_info_tree_leaf_count(&self) -> Option<u32>
pub fn l1_info_tree_leaf_count(&self) -> Option<u32>
Returns the L1 Info Tree leaf count considered for this Certificate.
Corresponds to the highest L1 Info Tree leaf index considered by the
imported bridge exits.
Sourcepub fn l1_info_root(&self) -> Result<Option<Digest>, Error>
pub fn l1_info_root(&self) -> Result<Option<Digest>, Error>
Returns the L1 Info Root considered for this Certificate.
Fails if multiple L1 Info Root are considered among the inclusion proofs
of the imported bridge exits.
pub fn signature_commitment_values(&self) -> SignatureCommitmentValues
pub fn verify_legacy_ecdsa( &self, expected_signer: Address, signature: &Signature, ) -> Result<(), SignerError>
pub fn verify_aggchain_proof_signature( &self, expected_signer: Address, signature: &Option<Box<Signature>>, ) -> Result<(), SignerError>
pub fn verify_multisig( &self, signatures: MultisigPayload, ctx: MultisigCtx, ) -> Result<(), SignerError>
pub fn aggchain_params(&self) -> Option<Digest>